# Change Log

## Kronolapse 0.2.0a1
- **Version 0.2.0 alpha 1 - 2026 enero 22.**
- Review of the source code (module and tests) with flake8 standards.
- Revision flake8 with acceptable result in kronolapse/*, tests/*, docs/source/*.
- _test_script_kronolapse.py_:
  * Addition 'except FileNotFoundError' to parse_command function.
  * Modified run command for compilation cross-platform.
- _Makefile_:
  * Added linter process for code review.
- First release on PyPI.
- Release Version 0.2.0

## Kronolapse 0.1.0a1
- **Version 0.1.0 alpha 1 - 2026 enero 08.**
- Initial release.
